@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2011 - 2012 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -75,9 +76,9 @@ TestCase test_cases[] = {
 };
 
 int 
-main (int argc, char **argv)
+main ()
 {
-	gint i;
+	guint i;
 
 	for (i = 0; i < (sizeof (test_cases) / sizeof (TestCase)); i++) {
 		TestCase *test = (TestCase*) &(test_cases[i]);
@@ -100,7 +101,7 @@ main (int argc, char **argv)
 		xmlNodePtr node;
 		xmlKeepBlanksDefault(0);
 		node = xmlNewNode (NULL, BAD_CAST "top");
-		parse_rich_text_to_docbook (node, test->in);
+		parse_rich_text_to_docbook (NULL, node, test->in);
 		xmlBufferPtr buf;
 		buf = xmlBufferCreate ();
 		xmlNodeDump (buf, NULL, node, 1, 1);
