@@ -1,6 +1,7 @@
 /*
  * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -336,7 +337,7 @@ gdaui_data_cell_renderer_password_set_property (GObject *object,
 
 /**
  * gdaui_data_cell_renderer_password_new
- * @dh: a #GdaDataHandler object, or %NULL
+ * @dh: (allow-none): a #GdaDataHandler object, or %NULL
  * @type: the #GType being edited
  *
  * Creates a new #GdauiDataCellRendererPassword.
@@ -386,19 +387,15 @@ gdaui_data_cell_renderer_password_render (GtkCellRenderer      *cell,
 	(text_class->render) (cell, cr, widget, background_area, cell_area, flags);
 
 	if (datacell->priv->to_be_deleted) {
-		GtkStyle *style;
+		GtkStyleContext *style_context = gtk_widget_get_style_context (widget);
 		guint xpad;
-
-		g_object_get ((GObject*) widget, "style", &style, NULL);
 		g_object_get ((GObject*) cell, "xpad", &xpad, NULL);
 
-		gtk_paint_hline (style,
-				 cr, GTK_STATE_SELECTED,
-				 widget,
-				 "hline",
+		gdouble y = cell_area->y + cell_area->height / 2.;
+		gtk_render_line (style_context,
+				 cr,
 				 cell_area->x + xpad, cell_area->x + cell_area->width - xpad,
-				 cell_area->y + cell_area->height / 2.);
-		g_object_unref (style);
+				 y, y);
 	}
 	if (datacell->priv->invalid)
 		gdaui_data_cell_renderer_draw_invalid_area (cr, cell_area);
