@@ -614,7 +614,7 @@ create_text (GtkTextBuffer **buffer,
   
 	if (is_source) {
 		font_desc = pango_font_description_from_string ("monospace");
-		gtk_widget_modify_font (text_view, font_desc);
+		gtk_widget_override_font (text_view, font_desc);
 		pango_font_description_free (font_desc);
 		
 		gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (text_view),
@@ -801,7 +801,7 @@ main (int argc, char **argv)
 	g_signal_connect (window, "destroy",
 			  G_CALLBACK (gtk_main_quit), NULL);
 
-	hbox = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_container_add (GTK_CONTAINER (window), hbox);
 
 	tree = create_tree ();
