@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -393,7 +393,7 @@ gdaui_tree_store_get_property (GObject *object,
  * gdaui_tree_store_new: (skip)
  * @tree: a #GdaTree object
  * @n_columns: number of columns in the tree store
- * @Varargs: couples of (GType, attribute name) for each column, from first to last 
+ * @...: couples of (GType, attribute name) for each column, from first to last 
  *
  * Creates a #GtkTreeModel interface with a #GdaTree, mapping columns to attributes' values.
  *
@@ -452,7 +452,7 @@ gdaui_tree_store_new (GdaTree *tree, guint n_columns, ...)
  * Creates a #GtkTreeModel interface with a #GdaTree, mapping columns to attributes' values.
  * For more information and limitations, see gdaui_tree_store_new().
  *
- * Returns: the new object, or %NULL if an inconsistency exists in the parameters
+ * Returns: (transfer full): the new object, or %NULL if an inconsistency exists in the parameters
  *
  * Since: 4.2
  */
@@ -519,9 +519,8 @@ gdaui_tree_store_get_node (GdauiTreeStore *store, GtkTreeIter *iter)
 	return node;
 }
 
-
 /**
- * gdaui_tree_store_get_iter:
+ * gdaui_tree_store_get_iter: (skip)
  * @store: a #GdauiTreeStore object
  * @iter: a pointer to a #GtkTreeIter
  * @node: a #GdaTreeNode in @store
@@ -531,9 +530,30 @@ gdaui_tree_store_get_node (GdauiTreeStore *store, GtkTreeIter *iter)
  * Returns: %TRUE if no error occurred and @iter is valid
  *
  * Since: 4.2.8
+ *
+ * Deprecated: 5.2
  */
 gboolean
 gdaui_tree_store_get_iter (GdauiTreeStore *store, GtkTreeIter *iter, GdaTreeNode *node)
+{
+	return gdaui_tree_store_get_iter_from_node (store, iter, node);
+}
+
+
+/**
+ * gdaui_tree_store_get_iter_from_node:
+ * @store: a #GdauiTreeStore object
+ * @iter: a #GtkTreeIter
+ * @node: a #GdaTreeNode in @store
+ *
+ * Sets @iter to represent @node in the tree.
+ *
+ * Returns: %TRUE if no error occurred and @iter is valid
+ *
+ * Since: 5.2
+ */
+gboolean
+gdaui_tree_store_get_iter_from_node (GdauiTreeStore *store, GtkTreeIter *iter, GdaTreeNode *node)
 {
 	g_return_val_if_fail (GDAUI_IS_TREE_STORE (store), FALSE);
 	g_return_val_if_fail (GDA_IS_TREE_NODE (node), FALSE);
