@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2006 - 2008 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2006 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2006 - 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2006 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2007 Brecht Sanders <brecht@edustria.be>
  * Copyright (C) 2009 Bas Driessen <bas.driessen@xobas.com>
  * Copyright (C) 2010 David King <davidk@openismus.com>
@@ -146,6 +146,9 @@ enum
 #define CSV_DATA_BUFFER_SIZE 2048
 
 static void gda_data_model_import_class_init (GdaDataModelImportClass *klass);
+static GObject *gda_data_model_import_constructor (GType type,
+						   guint n_construct_properties,
+						   GObjectConstructParam *construct_properties);
 static void gda_data_model_import_init       (GdaDataModelImport *model,
 					      GdaDataModelImportClass *klass);
 static void gda_data_model_import_dispose    (GObject *object);
@@ -189,7 +192,7 @@ gda_data_model_import_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (GdaDataModelImportClass),
 			(GBaseInitFunc) NULL,
@@ -209,12 +212,12 @@ gda_data_model_import_get_type (void)
 			NULL
 		};
 
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0) {
 			type = g_type_register_static (G_TYPE_OBJECT, "GdaDataModelImport", &info, 0);
 			g_type_add_interface_static (type, GDA_TYPE_DATA_MODEL, &data_model_info);
 		}
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 	return type;
 }
@@ -294,6 +297,7 @@ gda_data_model_import_class_init (GdaDataModelImportClass *klass)
 							       G_PARAM_CONSTRUCT));
 
 	/* virtual functions */
+	object_class->constructor = gda_data_model_import_constructor;
 	object_class->dispose = gda_data_model_import_dispose;
 	object_class->finalize = gda_data_model_import_finalize;
 }
@@ -329,7 +333,6 @@ gda_data_model_import_data_model_init (GdaDataModelIface *iface)
 static void
 gda_data_model_import_init (GdaDataModelImport *model, G_GNUC_UNUSED GdaDataModelImportClass *klass)
 {
-	g_return_if_fail (GDA_IS_DATA_MODEL_IMPORT (model));
 	model->priv = g_new0 (GdaDataModelImportPrivate, 1);
 	model->priv->random_access = FALSE; /* cursor mode is the default */
 	model->priv->columns = NULL;
@@ -351,6 +354,226 @@ gda_data_model_import_init (GdaDataModelImport *model, G_GNUC_UNUSED GdaDataMode
 	model->priv->strict = FALSE;
 }
 
+static void init_csv_import  (GdaDataModelImport *model);
+static void init_xml_import  (GdaDataModelImport *model);
+static void init_node_import (GdaDataModelImport *model);
+
+static GObject *
+gda_data_model_import_constructor (GType type,
+				   guint n_construct_properties,
+				   GObjectConstructParam *construct_properties)
+{
+	GObject *object;
+
+	/* construct parent */
+	object = G_OBJECT_CLASS (parent_class)->constructor (type,
+							     n_construct_properties,
+							     construct_properties);
+
+	/* parse construct properties */
+	GdaDataModelImport *model;
+	guint i;
+	model = GDA_DATA_MODEL_IMPORT (object);
+	for (i = 0; i< n_construct_properties; i++) {
+		GObjectConstructParam *prop = &(construct_properties[i]);
+		if (!strcmp (g_param_spec_get_name (prop->pspec), "random-access")) {
+			model->priv->random_access = g_value_get_boolean (prop->value);
+			if (model->priv->format == FORMAT_XML_NODE)
+				model->priv->random_access = TRUE;
+		}
+		else if (!strcmp (g_param_spec_get_name (prop->pspec), "filename")) {
+			const gchar *string;
+			string = g_value_get_string (prop->value);
+			if (!string)
+				continue;
+
+			model->priv->is_mapped = TRUE;
+			model->priv->src.mapped.filename = g_strdup (g_value_get_string (prop->value));
+
+			/* file opening */
+			model->priv->src.mapped.fd = open (model->priv->src.mapped.filename, O_RDONLY); /* Flawfinder: ignore */
+			if (model->priv->src.mapped.fd < 0) {
+				/* error */
+				add_error (model, strerror(errno));
+				continue;
+			}
+
+			/* file mmaping */
+			struct stat _stat;
+
+			if (fstat (model->priv->src.mapped.fd, &_stat) < 0) {
+				/* error */
+				add_error (model, strerror(errno));
+				continue;
+			}
+			model->priv->src.mapped.length = _stat.st_size;
+#ifndef G_OS_WIN32
+			model->priv->src.mapped.start = mmap (NULL, model->priv->src.mapped.length,
+							      PROT_READ, MAP_PRIVATE,
+							      model->priv->src.mapped.fd, 0);
+			if (model->priv->src.mapped.start == MAP_FAILED) {
+				/* error */
+				add_error (model, strerror(errno));
+				model->priv->src.mapped.start = NULL;
+				continue;
+			}
+#else
+			HANDLE hFile = CreateFile (model->priv->src.mapped.filename,
+						   GENERIC_READ,
+						   FILE_SHARE_READ,
+						   NULL,
+						   OPEN_EXISTING,
+						   FILE_ATTRIBUTE_NORMAL,
+						   NULL);
+			if (!hFile) {
+				LPVOID lpMsgBuf;
+				DWORD dw = GetLastError();
+				FormatMessage (FORMAT_MESSAGE_ALLOCATE_BUFFER |
+					       FORMAT_MESSAGE_FROM_SYSTEM |
+					       FORMAT_MESSAGE_IGNORE_INSERTS,
+					       NULL,
+					       dw,
+					       MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
+					       (LPTSTR) &lpMsgBuf,
+					       0, NULL);
+				add_error (model, (gchar *)lpMsgBuf);
+				continue;
+			}
+			HANDLE view = CreateFileMapping(hFile,
+							NULL, PAGE_READONLY|SEC_COMMIT, 0,0 , NULL);
+			if (!view) {
+				/* error */
+				LPVOID lpMsgBuf;
+				DWORD dw = GetLastError();
+				FormatMessage (FORMAT_MESSAGE_ALLOCATE_BUFFER |
+					       FORMAT_MESSAGE_FROM_SYSTEM |
+					       FORMAT_MESSAGE_IGNORE_INSERTS,
+					       NULL,
+					       dw,
+					       MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
+					       (LPTSTR) &lpMsgBuf,
+					       0, NULL);
+				add_error (model, (gchar *)lpMsgBuf);
+				continue;
+			}
+			model->priv->src.mapped.start = MapViewOfFile(view, FILE_MAP_READ, 0, 0,
+								      model->priv->src.mapped.length);
+			if (!model->priv->src.mapped.start) {
+				/* error */
+				LPVOID lpMsgBuf;
+				DWORD dw = GetLastError();
+				FormatMessage (FORMAT_MESSAGE_ALLOCATE_BUFFER |
+					       FORMAT_MESSAGE_FROM_SYSTEM |
+					       FORMAT_MESSAGE_IGNORE_INSERTS,
+					       NULL,
+					       dw,
+					       MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
+					       (LPTSTR) &lpMsgBuf,
+					       0, NULL);
+				add_error (model, (gchar *)lpMsgBuf);
+				continue;
+			}
+#endif
+			model->priv->data_start = model->priv->src.mapped.start;
+			model->priv->data_length = model->priv->src.mapped.length;
+		}
+		else if (!strcmp (g_param_spec_get_name (prop->pspec), "data-string")) {
+			const gchar *string;
+			string = g_value_get_string (prop->value);
+			if (!string)
+				continue;
+			model->priv->is_mapped = FALSE;
+			model->priv->src.string = g_strdup (g_value_get_string (prop->value));
+			model->priv->data_start = model->priv->src.string;
+			model->priv->data_length = strlen (model->priv->src.string);
+		}
+		else if (!strcmp (g_param_spec_get_name (prop->pspec), "xml-node")) {
+			gpointer data = g_value_get_pointer (prop->value);
+			if (!data)
+				continue;
+			model->priv->format = FORMAT_XML_NODE;
+			model->priv->extract.node.node = data;
+		}
+		else if (!strcmp (g_param_spec_get_name (prop->pspec), "options")) {
+			if (model->priv->options)
+				g_object_unref(model->priv->options);
+
+			model->priv->options = g_value_get_object (prop->value);
+			if (model->priv->options) {
+				if (!GDA_IS_SET (model->priv->options)) {
+					g_warning (_("\"options\" property is not a GdaSet object"));
+					model->priv->options = NULL;
+				}
+				else
+					g_object_ref (model->priv->options);
+			}
+		}
+		else if (!strcmp (g_param_spec_get_name (prop->pspec), "strict")) {
+			model->priv->strict = g_value_get_boolean (prop->value);
+		}
+	}
+
+	if (model->priv->errors)
+		return object;
+
+	/* finish construction */
+	/* determine the real kind of data (CVS text of XML) */
+	if (model->priv->format != FORMAT_XML_NODE
+	    && model->priv->data_start) {
+		if (!strncmp (model->priv->data_start, "<?xml", 5))
+			model->priv->format = FORMAT_XML_DATA;
+		else
+			model->priv->format = FORMAT_CSV;
+	}
+
+	/* analyze common options and init */
+	if (! model->priv->init_done) {
+		model->priv->init_done = TRUE;
+		switch (model->priv->format) {
+		case FORMAT_XML_DATA:
+			init_xml_import (model);
+			break;
+
+		case FORMAT_CSV:
+			model->priv->extract.csv.quote = '"';
+			if (model->priv->options) {
+				const gchar *option;
+				option = find_option_as_string (model, "ENCODING");
+				if (option)
+					model->priv->extract.csv.encoding = g_strdup (option);
+				option = find_option_as_string (model, "SEPARATOR");
+				if (option)
+					model->priv->extract.csv.delimiter = *option;
+				model->priv->extract.csv.quote = '"';
+				option = find_option_as_string (model, "QUOTE");
+				if (option)
+					model->priv->extract.csv.quote = *option;
+			}
+			init_csv_import (model);
+			break;
+
+		case FORMAT_XML_NODE:
+			model->priv->random_access = TRUE;
+			init_node_import (model);
+			break;
+		default:
+			g_assert_not_reached ();
+		}
+
+		/* for random access, create a new GdaDataModelArray model and copy the contents
+		   from this model */
+		if (model->priv->random_access && model->priv->columns && !model->priv->random_access_model) {
+			GdaDataModel *ramodel;
+
+			ramodel = gda_data_access_wrapper_new ((GdaDataModel *) model);
+			model->priv->random_access_model = ramodel;
+		}
+	}
+
+	return object;
+}
+
+
 static void
 csv_free_stored_rows (GdaDataModelImport *model)
 {
@@ -517,10 +740,6 @@ find_option_as_boolean (GdaDataModelImport *model, const gchar *pname, gboolean
 	return defaults;
 }
 
-static void init_csv_import  (GdaDataModelImport *model);
-static void init_xml_import  (GdaDataModelImport *model);
-static void init_node_import (GdaDataModelImport *model);
-
 static void
 gda_data_model_import_set_property (GObject *object,
 				    guint param_id,
@@ -533,138 +752,13 @@ gda_data_model_import_set_property (GObject *object,
 	model = GDA_DATA_MODEL_IMPORT (object);
 	if (model->priv) {
 		switch (param_id) {
-		case PROP_RANDOM_ACCESS:
-			model->priv->random_access = g_value_get_boolean (value);
-			if (model->priv->format == FORMAT_XML_NODE)
-				model->priv->random_access = TRUE;
-			return;
-			break;
-		case PROP_FILENAME:
-			string = g_value_get_string (value);
-			if (!string)
-				return;
-			model->priv->is_mapped = TRUE;
-			model->priv->src.mapped.filename = g_strdup (g_value_get_string (value));
-
-			/* file opening */
-			model->priv->src.mapped.fd = open (model->priv->src.mapped.filename, O_RDONLY); /* Flawfinder: ignore */
-			if (model->priv->src.mapped.fd < 0) {
-				/* error */
-				add_error (model, strerror(errno));
-				return;
-			}
-			else {
-				/* file mmaping */
-				struct stat _stat;
-
-				if (fstat (model->priv->src.mapped.fd, &_stat) < 0) {
-					/* error */
-					add_error (model, strerror(errno));
-					return;
-				}
-				model->priv->src.mapped.length = _stat.st_size;
-#ifndef G_OS_WIN32
-				model->priv->src.mapped.start = mmap (NULL, model->priv->src.mapped.length,
-								      PROT_READ, MAP_PRIVATE,
-								      model->priv->src.mapped.fd, 0);
-				if (model->priv->src.mapped.start == MAP_FAILED) {
-					/* error */
-					add_error (model, strerror(errno));
-					model->priv->src.mapped.start = NULL;
-					return;
-				}
-#else
-				HANDLE hFile = CreateFile (model->priv->src.mapped.filename,
-				                           GENERIC_READ,
-										   FILE_SHARE_READ,
-										   NULL,
-										   OPEN_EXISTING,
-										   FILE_ATTRIBUTE_NORMAL,
-										   NULL);
-				if (!hFile) {
-						LPVOID lpMsgBuf;
-						DWORD dw = GetLastError();
-						FormatMessage (FORMAT_MESSAGE_ALLOCATE_BUFFER |
-									   FORMAT_MESSAGE_FROM_SYSTEM |
-									   FORMAT_MESSAGE_IGNORE_INSERTS,
-									   NULL,
-									   dw,
-									   MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
-									   (LPTSTR) &lpMsgBuf,
-									   0, NULL);
-						add_error (model, (gchar *)lpMsgBuf);
-						return;
-				}
-				HANDLE view = CreateFileMapping(hFile,
-								NULL, PAGE_READONLY|SEC_COMMIT, 0,0 , NULL);
-				if (!view) {
-					/* error */
-					LPVOID lpMsgBuf;
-					DWORD dw = GetLastError();
-					FormatMessage (FORMAT_MESSAGE_ALLOCATE_BUFFER |
-					               FORMAT_MESSAGE_FROM_SYSTEM |
-								   FORMAT_MESSAGE_IGNORE_INSERTS,
-								   NULL,
-								   dw,
-								   MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
-								   (LPTSTR) &lpMsgBuf,
-								   0, NULL);
-					add_error (model, (gchar *)lpMsgBuf);
-					return;
-				}
-				model->priv->src.mapped.start = MapViewOfFile(view, FILE_MAP_READ, 0, 0,
-									      model->priv->src.mapped.length);
-				if (!model->priv->src.mapped.start) {
-					/* error */
-					LPVOID lpMsgBuf;
-					DWORD dw = GetLastError();
-					FormatMessage (FORMAT_MESSAGE_ALLOCATE_BUFFER |
-					               FORMAT_MESSAGE_FROM_SYSTEM |
-								   FORMAT_MESSAGE_IGNORE_INSERTS,
-								   NULL,
-								   dw,
-								   MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
-								   (LPTSTR) &lpMsgBuf,
-								   0, NULL);
-					add_error (model, (gchar *)lpMsgBuf);
-					return;
-				}
-#endif
-				model->priv->data_start = model->priv->src.mapped.start;
-				model->priv->data_length = model->priv->src.mapped.length;
-			}
-			break;
-		case PROP_DATA_STRING:
-			string = g_value_get_string (value);
-			if (!string)
-				return;
-			model->priv->is_mapped = FALSE;
-			model->priv->src.string = g_strdup (g_value_get_string (value));
-			model->priv->data_start = model->priv->src.string;
-			model->priv->data_length = strlen (model->priv->src.string);
-			break;
-		case PROP_XML_NODE: {
-			gpointer data = g_value_get_pointer (value);
-			if (!data)
-				return;
-			model->priv->format = FORMAT_XML_NODE;
-			model->priv->extract.node.node = data;
-			break;
-                }
 		case PROP_OPTIONS:
-                        if (model->priv->options)
-                          g_object_unref(model->priv->options);
-
-			model->priv->options = g_value_get_object (value);
-			if (model->priv->options) {
-				if (!GDA_IS_SET (model->priv->options)) {
-					g_warning (_("\"options\" property is not a GdaSet object"));
-					model->priv->options = NULL;
-				}
-				else
-					g_object_ref (model->priv->options);
-			}
-			return;
+		case PROP_XML_NODE:
+		case PROP_DATA_STRING:
+		case PROP_FILENAME:
+		case PROP_RANDOM_ACCESS:
+			/* handled in the constructor */
+			break;
 		case PROP_STRICT:
 			model->priv->strict = g_value_get_boolean (value);
 			break;
@@ -673,61 +767,6 @@ gda_data_model_import_set_property (GObject *object,
 			break;
 		}
 	}
-
-	/* here we now have a valid data to analyze, try to determine the real kind of data
-	 * (CVS text of XML) */
-	if (model->priv->format != FORMAT_XML_NODE
-	    && model->priv->data_start) {
-		if (!strncmp (model->priv->data_start, "<?xml", 5))
-			model->priv->format = FORMAT_XML_DATA;
-		else
-			model->priv->format = FORMAT_CSV;
-	}
-
-	/* analyze common options and init.
-	 * WARNING when adding properties: we need to avoid double initialization here... */
-	if (! model->priv->init_done) {
-		model->priv->init_done = TRUE;
-		switch (model->priv->format) {
-		case FORMAT_XML_DATA:
-			init_xml_import (model);
-			break;
-
-		case FORMAT_CSV:
-			model->priv->extract.csv.quote = '"';
-			if (model->priv->options) {
-				const gchar *option;
-				option = find_option_as_string (model, "ENCODING");
-				if (option)
-					model->priv->extract.csv.encoding = g_strdup (option);
-				option = find_option_as_string (model, "SEPARATOR");
-				if (option)
-					model->priv->extract.csv.delimiter = *option;
-				model->priv->extract.csv.quote = '"';
-				option = find_option_as_string (model, "QUOTE");
-				if (option)
-					model->priv->extract.csv.quote = *option;
-			}
-			init_csv_import (model);
-			break;
-
-		case FORMAT_XML_NODE:
-			model->priv->random_access = TRUE;
-			init_node_import (model);
-			break;
-		default:
-			g_assert_not_reached ();
-		}
-
-		/* for random access, create a new GdaDataModelArray model and copy the contents
-		   from this model */
-		if (model->priv->random_access && model->priv->columns && !model->priv->random_access_model) {
-			GdaDataModel *ramodel;
-
-			ramodel = gda_data_access_wrapper_new ((GdaDataModel *) model);
-			model->priv->random_access_model = ramodel;
-		}
-	}
 }
 
 static void
@@ -780,8 +819,8 @@ gda_data_model_import_get_property (GObject *object,
  *      <itemizedlist>
  *         <listitem><para>ENCODING (string): specifies the encoding of the data in the file</para></listitem>
  *         <listitem><para>SEPARATOR (string): specifies the CSV separator (comma as default)</para></listitem>
- *         <listitem><para>QUOTE (string): specifies the character used to as quote park (double quote as default)</para></listitem>
- *         <listitem><para>TITLE_AS_FIRST_LINE (boolean): consider that the first line of the file contains columns' titles</para></listitem>
+ *         <listitem><para>QUOTE (string): specifies the character used as quote (double quote as default)</para></listitem>
+ *         <listitem><para>NAMES_ON_FIRST_LINE (boolean): consider that the first line of the file contains columns' titles (note that the TITLE_AS_FIRST_LINE option is also accepted as a synonym)</para></listitem>
  *         <listitem><para>G_TYPE_&lt;column number&gt; (GType): specifies the type of value expected in column &lt;column number&gt;</para></listitem>
  *      </itemizedlist>
  *   </para></listitem>
@@ -870,7 +909,8 @@ init_csv_import (GdaDataModelImport *model)
 	gint nbcols;
 
 	if (model->priv->options)
-		title_first_line = find_option_as_boolean (model, "TITLE_AS_FIRST_LINE", FALSE);
+		title_first_line = find_option_as_boolean (model, "NAMES_ON_FIRST_LINE", FALSE) ||
+			find_option_as_boolean (model, "TITLE_AS_FIRST_LINE", FALSE);
 
 	g_assert (model->priv->format == FORMAT_CSV);
 
@@ -1017,9 +1057,11 @@ csv_parser_field_read_cb (char *s, size_t len, void *data)
 
 	/* compute column's type */
 	if (! model->priv->extract.csv.initializing) {
-		if (pdata->field_next_col >= pdata->nb_cols)
+		if (pdata->field_next_col >= pdata->nb_cols) {
 			/* ignore extra fields */
+			g_free (copy);
 			return;
+		}
 		column = gda_data_model_describe_column ((GdaDataModel *) model,
 							 pdata->field_next_col);
 		pdata->field_next_col++;
@@ -1697,7 +1739,7 @@ add_error (GdaDataModelImport *model, const gchar *err)
  * Get the list of errors which @model has to report. The returned list is a list of
  * #GError structures, and must not be modified
  *
- * Returns: (transfer none) (element-type GObject.Error): the list of errors (which must not be modified), or %NULL
+ * Returns: (transfer none) (element-type GLib.Error): the list of errors (which must not be modified), or %NULL
  */
 GSList *
 gda_data_model_import_get_errors (GdaDataModelImport *model)
@@ -1971,9 +2013,10 @@ gda_data_model_import_iter_next (GdaDataModel *model, GdaDataModelIter *iter)
 		     plist && vlist;
 		     plist = plist->next, vlist = vlist->next) {
 			GError *lerror = NULL;
-			if (! gda_holder_set_value (GDA_HOLDER (plist->data),
-						    (GValue *) vlist->data, &lerror))
+			if (! gda_holder_take_value ((GdaHolder*) plist->data,
+						     (GValue *) vlist->data, &lerror))
 				gda_holder_force_invalid_e (GDA_HOLDER (plist->data), lerror);
+			vlist->data = NULL;
 		}
 		if (plist || vlist) {
 			if (plist) {
@@ -2041,7 +2084,7 @@ gda_data_model_import_iter_prev (GdaDataModel *model, GdaDataModelIter *iter)
 		     plist && vlist;
 		     plist = plist->next, vlist = vlist->next) {
 			GError *lerror = NULL;
-			if (! gda_holder_set_value (GDA_HOLDER (plist->data),
+			if (! gda_holder_set_value ((GdaHolder*) plist->data,
 						    (GValue *) vlist->data, &lerror))
 				gda_holder_force_invalid_e (GDA_HOLDER (plist->data), lerror);
 		}
