@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2000 Reinhard Müller <reinhard@src.gnome.org>
  * Copyright (C) 2000 - 2002 Rodrigo Moya <rodrigo@gnome-db.org>
- * Copyright (C) 2001 Carlos Perell Marn <carlos@gnome-db.org>
+ * Copyright (C) 2001 Carlos Perelló Marín <carlos@gnome-db.org>
  * Copyright (C) 2001 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2002 Gonzalo Paniagua Javier <gonzalo@src.gnome.org>
  *
@@ -29,8 +29,6 @@
 G_BEGIN_DECLS
 
 GdaMetaDbObject    *_gda_meta_struct_add_db_object      (GdaMetaStruct *mstruct, GdaMetaDbObject *dbo, GError **error);
-gboolean            gda_meta_struct_load_from_xml_file (GdaMetaStruct *mstruct, const gchar *catalog, const gchar *schema, 
-							const gchar *xml_spec_file, GError **error);
 
 G_END_DECLS
 
