@@ -46,9 +46,6 @@ G_BEGIN_DECLS
 extern GQuark gda_server_provider_error_quark (void);
 #define GDA_SERVER_PROVIDER_ERROR gda_server_provider_error_quark ()
 
-/**
- * GdaServerProviderError:
- */
 typedef enum
 {
         GDA_SERVER_PROVIDER_METHOD_NON_IMPLEMENTED_ERROR,
@@ -67,9 +64,6 @@ typedef enum
 	GDA_SERVER_PROVIDER_FILE_NOT_FOUND_ERROR
 } GdaServerProviderError;
 
-/**
- * GdaServerProvider:
- */
 struct _GdaServerProvider {
 	GObject                   object;
 	GdaServerProviderPrivate *priv;
@@ -77,52 +71,52 @@ struct _GdaServerProvider {
 
 
 /**
- * GdaServerProviderMeta: (skip)
- * @_info:
- * @_btypes:
- * @_udt:
- * @udt:
- * @_udt_cols:
- * @udt_cols:
- * @_enums:
- * @enums:
- * @_domains:
- * @domains:
- * @_constraints_dom:
- * @constraints_dom:
- * @_el_types:
- * @el_types:
- * @_collations:
- * @collations:
- * @_character_sets:
- * @character_sets:
- * @_schemata:
- * @schemata:
- * @_tables_views:
- * @tables_views:
- * @_columns:
- * @columns:
- * @_view_cols:
- * @view_cols:
- * @_constraints_tab:
- * @constraints_tab:
- * @_constraints_ref:
- * @constraints_ref:
- * @_key_columns:
- * @key_columns:
- * @_check_columns:
- * @check_columns:
- * @_triggers:
- * @triggers:
- * @_routines:
- * @routines:
- * @_routine_col:
- * @routine_col:
- * @_routine_par:
- * @routine_par:
- * @_indexes_tab:
- * @indexes_tab:
- * @_index_cols:
+ * GdaServerProviderMeta:
+ * @_info: 
+ * @_btypes: 
+ * @_udt: 
+ * @udt: 
+ * @_udt_cols: 
+ * @udt_cols: 
+ * @_enums: 
+ * @enums: 
+ * @_domains: 
+ * @domains: 
+ * @_constraints_dom: 
+ * @constraints_dom: 
+ * @_el_types: 
+ * @el_types: 
+ * @_collations: 
+ * @collations: 
+ * @_character_sets: 
+ * @character_sets: 
+ * @_schemata: 
+ * @schemata: 
+ * @_tables_views: 
+ * @tables_views: 
+ * @_columns: 
+ * @columns: 
+ * @_view_cols: 
+ * @view_cols: 
+ * @_constraints_tab: 
+ * @constraints_tab: 
+ * @_constraints_ref: 
+ * @constraints_ref: 
+ * @_key_columns: 
+ * @key_columns: 
+ * @_check_columns: 
+ * @check_columns: 
+ * @_triggers: 
+ * @triggers: 
+ * @_routines: 
+ * @routines: 
+ * @_routine_col: 
+ * @routine_col: 
+ * @_routine_par: 
+ * @routine_par: 
+ * @_indexes_tab: 
+ * @indexes_tab: 
+ * @_index_cols: 
  * @index_cols:
  *
  * These methods must be implemented by providers to update a connection's associated metadata (in a 
@@ -131,160 +125,126 @@ struct _GdaServerProvider {
  */
 typedef struct {
 	/* _information_schema_catalog_name */
-	gboolean (*_info)            (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error);
+	gboolean (*_info)            (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
 
 	/* _builtin_data_types */
-	gboolean (*_btypes)          (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error);
+	gboolean (*_btypes)          (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
 
 	/* _udt */
-	gboolean (*_udt)             (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error);
-	gboolean (*udt)              (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error, const GValue *udt_catalog, const GValue *udt_schema);
+	gboolean (*_udt)             (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
+	gboolean (*udt)              (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error,
+				      const GValue *udt_catalog, const GValue *udt_schema);
 
 	/* _udt_columns */
-	gboolean (*_udt_cols)        (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error);
-	gboolean (*udt_cols)         (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error, const GValue *udt_catalog, const GValue *udt_schema,
-				      const GValue *udt_name);
+	gboolean (*_udt_cols)        (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
+	gboolean (*udt_cols)         (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error,
+				      const GValue *udt_catalog, const GValue *udt_schema, const GValue *udt_name);
 
 	/* _enums */
-	gboolean (*_enums)           (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error);
-	gboolean (*enums)            (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error, const GValue *udt_catalog, const GValue *udt_schema,
-				      const GValue *udt_name);
+	gboolean (*_enums)           (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
+	gboolean (*enums)            (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error,
+				      const GValue *udt_catalog, const GValue *udt_schema, const GValue *udt_name);
 
 	/* _domains */
-	gboolean (*_domains)         (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error);
-	gboolean (*domains)          (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-	GError **error, const GValue *domain_catalog, const GValue *domain_schema);
+	gboolean (*_domains)         (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
+	gboolean (*domains)          (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error,
+				      const GValue *domain_catalog, const GValue *domain_schema);
 
 	/* _domain_constraints */
-	gboolean (*_constraints_dom) (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error);
-	gboolean (*constraints_dom)  (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-	GError **error, const GValue *domain_catalog, const GValue *domain_schema, const GValue *domain_name);
+	gboolean (*_constraints_dom) (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
+	gboolean (*constraints_dom)  (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error,
+				      const GValue *domain_catalog, const GValue *domain_schema, const GValue *domain_name);
 
 	/* _element_types */
-	gboolean (*_el_types)        (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error);
-	gboolean (*el_types)         (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error, const GValue *specific_name);
+	gboolean (*_el_types)        (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
+	gboolean (*el_types)         (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error,
+				      const GValue *specific_name);
 
 	/* _collations */
-	gboolean (*_collations)       (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error);
-	gboolean (*collations)        (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error, const GValue *collation_catalog, const GValue *collation_schema,
-				      const GValue *collation_name_n);
+	gboolean (*_collations)       (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
+	gboolean (*collations)        (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error,
+				       const GValue *collation_catalog, const GValue *collation_schema, 
+				       const GValue *collation_name_n);
 
 	/* _character_sets */
-	gboolean (*_character_sets)  (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error);
-	gboolean (*character_sets)   (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error, const GValue *chset_catalog, const GValue *chset_schema,
-				      const GValue *chset_name_n);
+	gboolean (*_character_sets)  (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
+	gboolean (*character_sets)   (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error,
+				      const GValue *chset_catalog, const GValue *chset_schema, const GValue *chset_name_n);
 
 	/* _schemata */
-	gboolean (*_schemata)        (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error);
-	gboolean (*schemata)         (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error, const GValue *catalog_name, const GValue *schema_name_n);
+	gboolean (*_schemata)        (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
+	gboolean (*schemata)         (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error, 
+				      const GValue *catalog_name, const GValue *schema_name_n);
 
 	/* _tables or _views */
-	gboolean (*_tables_views)    (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-			      	GError **error);
-	gboolean (*tables_views)     (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error, const GValue *table_catalog, const GValue *table_schema,
-				      const GValue *table_name_n);
+	gboolean (*_tables_views)    (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
+	gboolean (*tables_views)     (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error,
+				      const GValue *table_catalog, const GValue *table_schema, const GValue *table_name_n);
 
 	/* _columns */
-	gboolean (*_columns)         (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error);
-	gboolean (*columns)          (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error, const GValue *table_catalog, const GValue *table_schema,
-				      const GValue *table_name);
+	gboolean (*_columns)         (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
+	gboolean (*columns)          (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error,
+				      const GValue *table_catalog, const GValue *table_schema, const GValue *table_name);
 
 	/* _view_column_usage */
-	gboolean (*_view_cols)       (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error);
-	gboolean (*view_cols)        (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error, const GValue *view_catalog, const GValue *view_schema,
-				      const GValue *view_name);
+	gboolean (*_view_cols)       (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
+	gboolean (*view_cols)        (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error,
+				      const GValue *view_catalog, const GValue *view_schema, const GValue *view_name);
 
 	/* _table_constraints */
-	gboolean (*_constraints_tab) (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error);
-	gboolean (*constraints_tab)  (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-			      	GError **error, const GValue *table_catalog, const GValue *table_schema,
-			      	const GValue *table_name, const GValue *constraint_name_n);
+	gboolean (*_constraints_tab) (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
+	gboolean (*constraints_tab)  (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error, 
+				      const GValue *table_catalog, const GValue *table_schema, const GValue *table_name,
+				      const GValue *constraint_name_n);
 
 	/* _referential_constraints */
-	gboolean (*_constraints_ref) (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error);
-	gboolean (*constraints_ref)  (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-			      	GError **error, const GValue *table_catalog, const GValue *table_schema,
-			      	const GValue *table_name, const GValue *constraint_name);
+	gboolean (*_constraints_ref) (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
+	gboolean (*constraints_ref)  (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error,
+				      const GValue *table_catalog, const GValue *table_schema, const GValue *table_name, 
+				      const GValue *constraint_name);
 
 	/* _key_column_usage */
-	gboolean (*_key_columns)     (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error);
-	gboolean (*key_columns)      (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error, const GValue *table_catalog, const GValue *table_schema,
-				      const GValue *table_name, const GValue *constraint_name);
+	gboolean (*_key_columns)     (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
+	gboolean (*key_columns)      (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error,
+				      const GValue *table_catalog, const GValue *table_schema, const GValue *table_name, 
+				      const GValue *constraint_name);
 
 	/* _check_column_usage */
-	gboolean (*_check_columns)   (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error);
-	gboolean (*check_columns)    (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-	GError **error, const GValue *table_catalog, const GValue *table_schema,
-			      	const GValue *table_name, const GValue *constraint_name);
+	gboolean (*_check_columns)   (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
+	gboolean (*check_columns)    (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error,
+				      const GValue *table_catalog, const GValue *table_schema, const GValue *table_name, 
+				      const GValue *constraint_name);
 
 	/* _triggers */
-	gboolean (*_triggers)        (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error);
-	gboolean (*triggers)         (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-			      	GError **error, const GValue *table_catalog, const GValue *table_schema,
-			      	const GValue *table_name);
+	gboolean (*_triggers)        (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
+	gboolean (*triggers)         (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error,
+				      const GValue *table_catalog, const GValue *table_schema, const GValue *table_name);
 
 	/* _routines */
-	gboolean (*_routines)       (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-			      	GError **error);
-	gboolean (*routines)        (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error, const GValue *routine_catalog, const GValue *routine_schema, 
-				      const GValue *routine_name_n);
+	gboolean (*_routines)       (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
+	gboolean (*routines)        (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error,
+				     const GValue *routine_catalog, const GValue *routine_schema, 
+				     const GValue *routine_name_n);
 
 	/* _routine_columns */
-	gboolean (*_routine_col)     (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error);
-	gboolean (*routine_col)      (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt, 
-				      GError **error, const GValue *rout_catalog, const GValue *rout_schema,
-				      const GValue *rout_name);
+	gboolean (*_routine_col)     (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
+	gboolean (*routine_col)      (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error,
+				      const GValue *rout_catalog, const GValue *rout_schema, const GValue *rout_name);
 
 	/* _parameters */
-	gboolean (*_routine_par)     (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error);
-	gboolean (*routine_par)      (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-			      	GError **error, const GValue *rout_catalog, const GValue *rout_schema,
-				      const GValue *rout_name);
+	gboolean (*_routine_par)     (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
+	gboolean (*routine_par)      (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error,
+				      const GValue *rout_catalog, const GValue *rout_schema, const GValue *rout_name);
 	/* _table_indexes */
-	gboolean (*_indexes_tab)     (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error);
-	gboolean (*indexes_tab)      (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error, const GValue *table_catalog, const GValue *table_schema,
-				      const GValue *table_name, const GValue *index_name_n);
+	gboolean (*_indexes_tab)     (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
+	gboolean (*indexes_tab)      (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error, 
+				      const GValue *table_catalog, const GValue *table_schema, const GValue *table_name,
+				      const GValue *index_name_n);
 
 	/* _index_column_usage */
-	gboolean (*_index_cols)      (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error);
-	gboolean (*index_cols)       (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *store, GdaMetaContext *cxt,
-				      GError **error, const GValue *table_catalog, const GValue *table_schema,
-				      const GValue *table_name, const GValue *index_name);
+	gboolean (*_index_cols)      (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error);
+	gboolean (*index_cols)       (GdaServerProvider *prov, GdaConnection *cnc, GdaMetaStore *meta, GdaMetaContext *ctx, GError **error,
+				      const GValue *table_catalog, const GValue *table_schema, const GValue *table_name, const GValue *index_name);
 	
 	/*< private >*/
 	/* Padding for future expansion */
@@ -304,17 +264,14 @@ typedef struct {
 } GdaServerProviderMeta;
 
 /* distributed transaction support */
-/**
- * GdaServerProviderXa: (skip)
- */
 typedef struct {
-	gboolean (*xa_start)    (GdaServerProvider *prov, GdaConnection *cnc, const GdaXaTransactionId *trid, GError **error);
+	gboolean (*xa_start)    (GdaServerProvider *prov, GdaConnection *cnc, const GdaXaTransactionId *trx, GError **error);
 
-	gboolean (*xa_end)      (GdaServerProvider *prov, GdaConnection *cnc, const GdaXaTransactionId *trid, GError **error);
-	gboolean (*xa_prepare)  (GdaServerProvider *prov, GdaConnection *cnc, const GdaXaTransactionId *trid, GError **error);
+	gboolean (*xa_end)      (GdaServerProvider *prov, GdaConnection *cnc, const GdaXaTransactionId *trx, GError **error);
+	gboolean (*xa_prepare)  (GdaServerProvider *prov, GdaConnection *cnc, const GdaXaTransactionId *trx, GError **error);
 
-	gboolean (*xa_commit)   (GdaServerProvider *prov, GdaConnection *cnc, const GdaXaTransactionId *trid, GError **error);
-	gboolean (*xa_rollback) (GdaServerProvider *prov, GdaConnection *cnc, const GdaXaTransactionId *trid, GError **error);
+	gboolean (*xa_commit)   (GdaServerProvider *prov, GdaConnection *cnc, const GdaXaTransactionId *trx, GError **error);
+	gboolean (*xa_rollback) (GdaServerProvider *prov, GdaConnection *cnc, const GdaXaTransactionId *trx, GError **error);
 
 	GList   *(*xa_recover)  (GdaServerProvider *prov, GdaConnection *cnc, GError **error);
 } GdaServerProviderXa;
@@ -405,14 +362,13 @@ struct _GdaServerProviderClass {
 	/* GdaStatement */
 	GdaSqlParser           *(* create_parser)        (GdaServerProvider *provider, GdaConnection *cnc);
 	
-/**
- * statement_to_sql:
- * @provider: a #GdaServerProvider object
- * @cnc: a #GdaConnection object
- * @stmt: a #GdaStatement object
- * @params: (allow-none): a #GdaSet object (which can be obtained using gda_statement_get_parameters()), or %NULL
- * @flags: SQL rendering flags, as #GdaStatementSqlFlag OR'ed values
- * @params_used: (allow-none) (element-type Gda.Holder) (out) (transfer container): a place to store the list of individual #GdaHolder objects within @params which have been used
+	/**
+	 * statement_to_sql:
+	 * @cnc: a #GdaConnection object
+	 * @stmt: a #GdaStatement object
+	 * @params: (allow-none): a #GdaSet object (which can be obtained using gda_statement_get_parameters()), or %NULL
+	 * @flags: SQL rendering flags, as #GdaStatementSqlFlag OR'ed values
+	 * @params_used: (allow-none) (element-type Gda.Holder) (out) (transfer container): a place to store the list of individual #GdaHolder objects within @params which have been used
 	 * @error: a place to store errors, or %NULL
 	 *
 	 * Renders @stmt as an SQL statement, adapted to the SQL dialect used by @cnc
@@ -432,8 +388,7 @@ struct _GdaServerProviderClass {
 							  gpointer cb_data, GError **error);
 
 	/* Misc */
-	gboolean                (* is_busy)              (GdaServerProvider *provider, GdaConnection *cnc,
-				        GError **error);
+	gboolean                (* is_busy)              (GdaServerProvider *provider, GdaConnection *cnc, GError **error);
 	gboolean                (* cancel)               (GdaServerProvider *provider, GdaConnection *cnc, 
 							  guint task_id, GError **error);
 	GdaConnection          *(* create_connection)    (GdaServerProvider *provider);
@@ -446,7 +401,8 @@ struct _GdaServerProviderClass {
 
 	/* SQL identifiers quoting */
 	gchar                  *(* identifier_quote)    (GdaServerProvider *provider, GdaConnection *cnc,
-							 const gchar *id, gboolean for_meta_store, gboolean force_quotes);
+							 const gchar *id,
+							 gboolean for_meta_store, gboolean force_quotes);
 
 	/* Async. handling */
 	gboolean                (*handle_async)         (GdaServerProvider *provider, GdaConnection *cnc, GError **error);
