@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -155,7 +155,7 @@ gda_tree_mgr_tables_dispose (GObject *object)
 }
 
 /**
- * gda_tree_mgr_select_get_type:
+ * gda_tree_mgr_tables_get_type:
  *
  * Returns: the GType
  *
@@ -167,7 +167,7 @@ gda_tree_mgr_tables_get_type (void)
         static GType type = 0;
 
         if (G_UNLIKELY (type == 0)) {
-                static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+                static GMutex registering;
                 static const GTypeInfo info = {
                         sizeof (GdaTreeMgrTablesClass),
                         (GBaseInitFunc) NULL,
@@ -181,10 +181,10 @@ gda_tree_mgr_tables_get_type (void)
 			0
                 };
 
-                g_static_mutex_lock (&registering);
+                g_mutex_lock (&registering);
                 if (type == 0)
                         type = g_type_register_static (GDA_TYPE_TREE_MANAGER, "GdaTreeMgrTables", &info, 0);
-                g_static_mutex_unlock (&registering);
+                g_mutex_unlock (&registering);
         }
         return type;
 }
