@@ -27,6 +27,7 @@
 #include "gda-tree.h"
 #include "gda-tree-manager.h"
 #include "gda-tree-node.h"
+#include <libgda/gda-debug-macros.h>
 
 struct _GdaTreePrivate {
 	GSList      *managers; /* list of GdaTreeManager */
@@ -63,7 +64,7 @@ enum {
 };
 
 static gint gda_tree_signals[LAST_SIGNAL] = { 0, 0, 0, 0 };
-extern GdaAttributesManager *gda_tree_node_attributes_manager;
+extern GdaAttributesManager *_gda_tree_node_attributes_manager;
 
 /* properties */
 enum {
@@ -86,7 +87,7 @@ gda_tree_class_init (GdaTreeClass *klass)
 
 	/* signals */
 	/**
-	 * GdaTree::node-changed
+	 * GdaTree::node-changed:
 	 * @tree: the #GdaTree
 	 * @node: the #GdaTreeNode which has changed
 	 *
@@ -103,7 +104,7 @@ gda_tree_class_init (GdaTreeClass *klass)
 			      g_cclosure_marshal_VOID__OBJECT,
 			      G_TYPE_NONE, 1, GDA_TYPE_TREE_NODE);
 	/**
-	 * GdaTree::node-inserted
+	 * GdaTree::node-inserted:
 	 * @tree: the #GdaTree
 	 * @node: the #GdaTreeNode which has inserted
 	 *
@@ -120,7 +121,7 @@ gda_tree_class_init (GdaTreeClass *klass)
 			      g_cclosure_marshal_VOID__OBJECT,
 			      G_TYPE_NONE, 1, GDA_TYPE_TREE_NODE);
 	/**
-	 * GdaTree::node-has-child-toggled
+	 * GdaTree::node-has-child-toggled:
 	 * @tree: the #GdaTree
 	 * @node: the #GdaTreeNode which changed from having children to being a
 	 *        leaf or the other way around
@@ -139,7 +140,7 @@ gda_tree_class_init (GdaTreeClass *klass)
 			      g_cclosure_marshal_VOID__OBJECT,
 			      G_TYPE_NONE, 1, GDA_TYPE_TREE_NODE);
 	/**
-	 * GdaTree::node-deleted
+	 * GdaTree::node-deleted:
 	 * @tree: the #GdaTree
 	 * @node_path: the position the node held in @tree as a tree path
 	 *
@@ -235,7 +236,7 @@ gda_tree_get_type (void)
         static GType type = 0;
 
         if (G_UNLIKELY (type == 0)) {
-                static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+                static GMutex registering;
                 static const GTypeInfo info = {
                         sizeof (GdaTreeClass),
                         (GBaseInitFunc) NULL,
@@ -249,10 +250,10 @@ gda_tree_get_type (void)
 			0
                 };
 
-                g_static_mutex_lock (&registering);
+                g_mutex_lock (&registering);
                 if (type == 0)
                         type = g_type_register_static (G_TYPE_OBJECT, "GdaTree", &info, 0);
-                g_static_mutex_unlock (&registering);
+                g_mutex_unlock (&registering);
         }
         return type;
 }
@@ -350,7 +351,7 @@ static void
 dump_root_attributes (GdaTreeNode *root)
 {
 	g_print ("DUMPING attributes for %p\n", root);
-	gda_attributes_manager_foreach (gda_tree_node_attributes_manager, root,
+	gda_attributes_manager_foreach (_gda_tree_node_attributes_manager, root,
 					(GdaAttributesManagerFunc) dump_attr_foreach_func, NULL);
 }
 #endif
@@ -373,8 +374,8 @@ gda_tree_clean (GdaTree *tree)
 
 	new_root = gda_tree_node_new (NULL);
 
-	gda_attributes_manager_copy (gda_tree_node_attributes_manager, (gpointer) tree->priv->root,
-				     gda_tree_node_attributes_manager, (gpointer) new_root);
+	gda_attributes_manager_copy (_gda_tree_node_attributes_manager, (gpointer) tree->priv->root,
+				     _gda_tree_node_attributes_manager, (gpointer) new_root);
 
 	take_root_node (tree, new_root);
 }
@@ -749,7 +750,7 @@ static GSList *split_absolute_path (const gchar *path, gboolean *out_error);
 static GSList *split_indexed_path (const gchar *path, gboolean *out_error);
 
 /**
- * decompose_path_as_segments
+ * decompose_path_as_segments:
  * @path: a path using '/'
  * @use_names: 
  *
