@@ -220,7 +220,7 @@ gda_xa_transaction_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static GTypeInfo info = {
 			sizeof (GdaXaTransactionClass),
 			(GBaseInitFunc) NULL,
@@ -232,10 +232,10 @@ gda_xa_transaction_get_type (void)
 			(GInstanceInitFunc) gda_xa_transaction_init,
 			0
 		};
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (G_TYPE_OBJECT, "GdaXaTransaction", &info, 0);
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 
 	return type;
