@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2001 - 2002 Carlos Perell Marn <carlos@gnome-db.org>
+ * Copyright (C) 2001 - 2002 Carlos Perelló Marín <carlos@gnome-db.org>
  * Copyright (C) 2001 - 2002 Rodrigo Moya <rodrigo@gnome-db.org>
- * Copyright (C) 2001 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2001 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2002 - 2003 Gonzalo Paniagua Javier <gonzalo@src.gnome.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
  *
@@ -248,12 +248,12 @@ sqlite_remove_quotes (gchar *str)
         total = strlen (str);
         if ((str[total-1] == delim) || ((delim == '[') && (str[total-1] == ']'))) {
 		/* string is correctly terminated */
-		g_memmove (str, str+1, total-2);
+		memmove (str, str+1, total-2);
 		total -=2;
 	}
 	else {
 		/* string is _not_ correctly terminated */
-		g_memmove (str, str+1, total-1);
+		memmove (str, str+1, total-1);
 		total -=1;
 	}
         str[total] = 0;
@@ -264,7 +264,7 @@ sqlite_remove_quotes (gchar *str)
 			/* we accept the "''" as a synonym of "\'" */
 			if (*ptr == delim) {
 				if (*(ptr+1) == delim) {
-					g_memmove (ptr+1, ptr+2, total - offset);
+					memmove (ptr+1, ptr+2, total - offset);
 					offset += 2;
 				}
 				else {
@@ -274,7 +274,7 @@ sqlite_remove_quotes (gchar *str)
 			}
 			else if (*ptr == '"') {
 				if (*(ptr+1) == '"') {
-					g_memmove (ptr+1, ptr+2, total - offset);
+					memmove (ptr+1, ptr+2, total - offset);
 					offset += 2;
 				}
 				else {
@@ -284,13 +284,13 @@ sqlite_remove_quotes (gchar *str)
 			}
 			else if (*ptr == '\\') {
 				if (*(ptr+1) == '\\') {
-					g_memmove (ptr+1, ptr+2, total - offset);
+					memmove (ptr+1, ptr+2, total - offset);
 					offset += 2;
 				}
 				else {
 					if (*(ptr+1) == delim) {
 						*ptr = delim;
-						g_memmove (ptr+1, ptr+2, total - offset);
+						memmove (ptr+1, ptr+2, total - offset);
 						offset += 2;
 					}
 					else {
@@ -315,10 +315,6 @@ _gda_sqlite_identifier_quote (G_GNUC_UNUSED GdaServerProvider *provider, GdaConn
 			     gboolean for_meta_store, gboolean force_quotes)
 {
         GdaSqlReservedKeywordsFunc kwfunc;
-        SqliteConnectionData *cdata = NULL;
-
-        if (cnc)
-                cdata = (SqliteConnectionData*) gda_connection_internal_get_provider_data (cnc);
         kwfunc = _gda_sqlite_get_reserved_keyword_func ();
 
 	if (for_meta_store) {
