@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2006 - 2009 Bas Driessen <bas.driessen@xobas.com>
- * Copyright (C) 2006 - 2010 Vivien Malerba <malerba@gnome-db.org>
- * Copyright (C) 2008 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2006 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -252,7 +252,7 @@ gda_mysql_render_CREATE_TABLE (GdaServerProvider *provider, GdaConnection *cnc,
 		if (node) {
 			nrows = gda_server_operation_get_sequence_size (op, "/FKEY_S");
 			for (i = 0; i < nrows; i++) {
-				gint nbfields, j;
+				gint nbfields = 0, j;
 
 				g_string_append (string, ", FOREIGN KEY (");
 				node = gda_server_operation_get_node_info (op, "/FKEY_S/%d/FKEY_FIELDS_A", i);
