@@ -48,4 +48,11 @@ typedef struct {
 	MYSQL             *mysql;	
 } MysqlConnectionData;
 
+// Makes back my_bool
+#ifdef MYSQL8
+
+typedef bool my_bool;
+
+#endif
+
 #endif
