@@ -33,7 +33,7 @@
 #include <libgda/gda-data-model-array.h>
 #include <libgda/gda-set.h>
 #include <libgda/gda-holder.h>
-
+#include <libgda/gda-debug-macros.h>
 #include <libgda/sqlite/keywords_hash.h>
 #include "keywords_hash.c" /* this one is dynamically generated */
 
@@ -56,7 +56,7 @@ static gchar *internal_sql[] = {
  * global static values, and
  * predefined statements' GdaStatement, all initialized in _gda_capi_provider_meta_init()
  */
-static GStaticMutex init_mutex = G_STATIC_MUTEX_INIT;
+static GMutex init_mutex;
 static GdaStatement **internal_stmt = NULL;
 static GdaSet        *i_set = NULL;
 static GdaSqlParser  *internal_parser = NULL;
@@ -69,7 +69,7 @@ static GdaSqlParser  *internal_parser = NULL;
 void
 _gda_capi_provider_meta_init (GdaServerProvider *provider)
 {
-	g_static_mutex_lock (&init_mutex);
+	g_mutex_lock (&init_mutex);
 
 	if (!internal_stmt) {
 		InternalStatementItem i;
@@ -88,7 +88,7 @@ _gda_capi_provider_meta_init (GdaServerProvider *provider)
 					    "name2", G_TYPE_STRING, "");
 	}
 
-	g_static_mutex_unlock (&init_mutex);
+	g_mutex_unlock (&init_mutex);
 
 #ifdef GDA_DEBUG
 	/* make sure the reserved keywords hash works correctly */
