@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2008 Murray Cumming <murrayc@murrayc.com>
- * Copyright (C) 2008 - 2010 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2008 - 2012 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -72,7 +72,10 @@ TestFunc tests[] = {
 int 
 main (int argc, char** argv)
 {
+#if GLIB_CHECK_VERSION(2,36,0)
+#else
 	g_type_init ();
+#endif
 	gda_init ();
 
 	guint failures = 0;
@@ -110,7 +113,7 @@ test1 (GError **error)
 	emitted_signals_monitor_holder (h);
 	cvalue = gda_holder_get_value (h);
 	if (!gda_value_is_null (cvalue)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "Expecting NULL value from new GdaHolder");
 		return FALSE;
 	}
@@ -127,7 +130,7 @@ test1 (GError **error)
 
 	cvalue = gda_holder_get_value (h);
 	if (!cvalue || gda_value_compare (value, cvalue)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value is incorrect");
 		return FALSE;
 	}
@@ -146,7 +149,7 @@ test1 (GError **error)
 
 	cvalue = gda_holder_get_value (h);
 	if (!cvalue || gda_value_compare (copy, cvalue)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value is incorrect");
 		return FALSE;
 	}
@@ -170,13 +173,13 @@ test2 (GError **error)
 	value = gda_value_new_from_string ("TRUE", G_TYPE_BOOLEAN);
 	cvalue = gda_holder_get_value (h);
 	if (!cvalue || gda_value_compare (value, cvalue)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value is incorrect");
 		return FALSE;
 	}
 	gda_value_free (value);
 	if (strcmp (gda_holder_get_id (h), "ABOOL")) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's ID is incorrect");
 		return FALSE;
 	}
@@ -187,13 +190,13 @@ test2 (GError **error)
 	value = gda_value_new_from_string ("A string value", G_TYPE_STRING);
 	cvalue = gda_holder_get_value (h);
 	if (!cvalue || gda_value_compare (value, cvalue)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value is incorrect");
 		return FALSE;
 	}
 	gda_value_free (value);
 	if (strcmp (gda_holder_get_id (h), "Astring")) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's ID is incorrect");
 		return FALSE;
 	}
@@ -203,13 +206,13 @@ test2 (GError **error)
 	value = gda_value_new_from_string ("15", G_TYPE_INT);
 	cvalue = gda_holder_get_value (h);
 	if (!cvalue || gda_value_compare (value, cvalue)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value is incorrect");
 		return FALSE;
 	}
 	gda_value_free (value);
 	if (strcmp (gda_holder_get_id (h), "AnInt")) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's ID is incorrect");
 		return FALSE;
 	}
@@ -232,7 +235,7 @@ test3 (GError **error)
 	h = gda_holder_new_boolean ("ABOOL", TRUE);
 	emitted_signals_monitor_holder (h);
 	if (!gda_holder_is_valid (h)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder is invalid");
 		return FALSE;
 	}
@@ -240,13 +243,13 @@ test3 (GError **error)
 	/***/
 	gda_holder_force_invalid (h);
 	if (gda_holder_is_valid (h)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder is valid");
 		return FALSE;
 	}
 	cvalue = gda_holder_get_value (h);
 	if (cvalue) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value is incorrect");
 		return FALSE;
 	}
@@ -257,7 +260,7 @@ test3 (GError **error)
 	if (! gda_holder_take_value (h, value, error))
 		return FALSE;
 	if (!gda_holder_is_valid (h)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder is invalid");
 		return FALSE;
 	}
@@ -287,14 +290,14 @@ test4 (GError **error)
 	
 	cvalue = gda_holder_get_default_value (h);
 	if (cvalue) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder should not have a default value");
 		return FALSE;
 	}
 
 	/***/
 	if (gda_holder_set_value_to_default (h)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "Should not set GdaHolder's value to default");
 		return FALSE;
 	}
@@ -309,7 +312,7 @@ test4 (GError **error)
 
 	cvalue = gda_holder_get_default_value (h);
 	if (!cvalue || gda_value_compare (value, cvalue)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's default value is invalid");
 		return FALSE;
 	}
@@ -317,14 +320,14 @@ test4 (GError **error)
 
 	/***/
 	if (gda_holder_value_is_default (h)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value should not be default");
 		return FALSE;
 	}
 
 	/** Check value */
 	if (! gda_holder_set_value_to_default (h)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "Could not set GdaHolder's value to default");
 		return FALSE;
 	}
@@ -336,7 +339,7 @@ test4 (GError **error)
 	cvalue = gda_holder_get_value (h);
 	if (cvalue) {
 		tests_common_display_value ("cvalue", cvalue);
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value is invalid");
 		return FALSE;
 	}
@@ -353,7 +356,7 @@ test4 (GError **error)
 	cvalue = gda_holder_get_value (h);
 	if (!cvalue || gda_value_compare (value, cvalue)) {
 		tests_common_display_value ("cvalue", cvalue);
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value is invalid");
 		return FALSE;
 	}
@@ -367,7 +370,7 @@ test4 (GError **error)
 
 	cvalue = gda_holder_get_default_value (h);
 	if (!cvalue || gda_value_compare (value, cvalue)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's default value is invalid");
 		return FALSE;
 	}
@@ -375,7 +378,7 @@ test4 (GError **error)
 
 	/***/
 	if (gda_holder_value_is_default (h)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value should not be default");
 		return FALSE;
 	}
@@ -401,7 +404,7 @@ test5 (GError **error)
 
 	cvalue = gda_holder_get_default_value (h);
 	if (cvalue) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder should not have a default value");
 		return FALSE;
 	}
@@ -414,21 +417,21 @@ test5 (GError **error)
 
 	cvalue = gda_holder_get_default_value (h);
 	if (!cvalue || gda_value_compare (defvalue, cvalue)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's default value is invalid");
 		return FALSE;
 	}
 
 	/***/
 	if (gda_holder_value_is_default (h)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value should not be default");
 		return FALSE;
 	}
 
 	/** Check value */
 	if (! gda_holder_set_value_to_default (h)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "Could not set GdaHolder's value to default");
 		return FALSE;
 	}
@@ -440,7 +443,7 @@ test5 (GError **error)
 	cvalue = gda_holder_get_value (h);
 	if (!cvalue || gda_value_compare (defvalue, cvalue)) {
 		tests_common_display_value ("cvalue", cvalue);
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value is invalid");
 		return FALSE;
 	}
@@ -457,7 +460,7 @@ test5 (GError **error)
 	cvalue = gda_holder_get_value (h);
 	if (!cvalue || gda_value_compare (value, cvalue)) {
 		tests_common_display_value ("cvalue", cvalue);
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value is invalid");
 		return FALSE;
 	}
@@ -465,7 +468,7 @@ test5 (GError **error)
 	
 	/***/
 	if (gda_holder_value_is_default (h)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value should not be default");
 		return FALSE;
 	}
@@ -482,7 +485,7 @@ test5 (GError **error)
 	cvalue = gda_holder_get_value (h);
 	if (!cvalue || gda_value_compare (value, cvalue)) {
 		tests_common_display_value ("cvalue", cvalue);
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value is invalid");
 		return FALSE;
 	}
@@ -490,7 +493,7 @@ test5 (GError **error)
 
 	/***/
 	if (!gda_holder_value_is_default (h)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value should be default");
 		return FALSE;
 	}
@@ -516,7 +519,7 @@ test6 (GError **error)
 	emitted_signals_monitor_holder (h);
 	emitted_signals_reset ();
 	if (cvalue) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder should not have a default value");
 		return FALSE;
 	}
@@ -529,21 +532,21 @@ test6 (GError **error)
 
 	cvalue = gda_holder_get_default_value (h);
 	if (!cvalue || gda_value_compare (defvalue, cvalue)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's default value is invalid");
 		return FALSE;
 	}
 
 	/***/
 	if (gda_holder_value_is_default (h)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value should not be default");
 		return FALSE;
 	}
 
 	/** Check value */
 	if (! gda_holder_set_value_to_default (h)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "Could not set GdaHolder's value to default");
 		return FALSE;
 	}
@@ -555,7 +558,7 @@ test6 (GError **error)
 	cvalue = gda_holder_get_value (h);
 	if (cvalue) {
 		tests_common_display_value ("cvalue", cvalue);
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value is invalid");
 		return FALSE;
 	}
@@ -567,7 +570,7 @@ test6 (GError **error)
 	cvalue = gda_holder_get_value (h);
 	if (!cvalue || gda_value_compare (value, cvalue)) {
 		tests_common_display_value ("cvalue", cvalue);
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value is invalid");
 		return FALSE;
 	}
@@ -575,7 +578,7 @@ test6 (GError **error)
 	
 	/***/
 	if (gda_holder_value_is_default (h)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value should not be default");
 		return FALSE;
 	}
@@ -615,7 +618,7 @@ test7 (GError **error)
 	cvalue = gda_holder_get_value (h1);
 	if (!cvalue || gda_value_compare (value, cvalue)) {
 		tests_common_display_value ("Slave", cvalue);
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "Slave GdaHolder's value is wrong");
 		return FALSE;
 	}
@@ -635,7 +638,7 @@ test7 (GError **error)
 	cvalue = gda_holder_get_value (h1);
 	if (!cvalue || gda_value_compare (value, cvalue)) {
 		tests_common_display_value ("Slave", cvalue);
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "Slave GdaHolder's value is wrong");
 		return FALSE;
 	}
@@ -654,13 +657,13 @@ test7 (GError **error)
 
 	cvalue = gda_holder_get_value (h2);
 	if (!cvalue || gda_value_compare (value, cvalue)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "Master GdaHolder's value is wrong");
 		return FALSE;
 	}
 	cvalue = gda_holder_get_value (h1);
 	if (!cvalue || gda_value_compare (value, cvalue)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "Slave GdaHolder's value is wrong");
 		return FALSE;
 	}
@@ -673,7 +676,7 @@ test7 (GError **error)
 
 	cvalue = gda_holder_get_value (h1);
 	if (!cvalue || gda_value_compare (value, cvalue)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "Slave GdaHolder's value is wrong");
 		return FALSE;
 	}
@@ -691,14 +694,14 @@ test7 (GError **error)
 
 	cvalue = gda_holder_get_value (h1);
 	if (!cvalue || gda_value_compare (value, cvalue)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "Slave GdaHolder's value is wrong");
 		return FALSE;
 	}
 
 	cvalue = gda_holder_get_value (h2);
 	if (!cvalue || !gda_value_compare (value, cvalue)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "Master GdaHolder's value is wrong");
 		return FALSE;
 	}
@@ -735,7 +738,7 @@ test8 (GError **error)
 
 	/***/
 	if (!gda_holder_value_is_default (h)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value should be default");
 		return FALSE;
 	}
@@ -769,7 +772,7 @@ test9 (GError **error)
 		return FALSE;
 
 	if ((gda_holder_get_source_model (h, &col) != model) || (col != 1)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's source is wrong");
 		return FALSE;
 	}
@@ -782,7 +785,7 @@ test9 (GError **error)
 	if (!emitted_signals_check_empty (NULL, "source-changed", error))
 		return FALSE;
 	if ((gda_holder_get_source_model (h, &col) != model) || (col != 0)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's source is wrong");
 		return FALSE;
 	}
@@ -796,7 +799,7 @@ test9 (GError **error)
 		return FALSE;
 
 	if (gda_holder_get_source_model (h, NULL)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's source should be NULL");
 		return FALSE;
 	}
@@ -824,7 +827,7 @@ t10_validate_change_cb (GdaHolder *h, const GValue *value, gchar *token)
 	else {
 		GError *error = NULL;
 		g_print ("GdaHolder change refused\n");
-		g_set_error (&error, 0, 0,
+		g_set_error (&error, TEST_ERROR, TEST_ERROR_GENERIC,
 			     "%s", "GdaHolder change refused!");
 		return error;
 	}
@@ -859,7 +862,7 @@ test10 (GError **error)
 	value = gda_value_new_from_string ("my other string", G_TYPE_STRING);
 	emitted_signals_reset ();
 	if (gda_holder_set_value (h, value, error)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's change should have failed");
 		return FALSE;
 	}
@@ -871,7 +874,7 @@ test10 (GError **error)
 	value = gda_value_new_from_string ("my string", G_TYPE_STRING);
 	cvalue = gda_holder_get_value (h);
 	if (!cvalue || gda_value_differ (value, cvalue)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value is incorrect");
 		return FALSE;
 	}
@@ -891,7 +894,7 @@ test10 (GError **error)
 	/***/
 	cvalue = gda_holder_get_value (h);
 	if (!cvalue || gda_value_differ (value, cvalue)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value is incorrect");
 		return FALSE;
 	}
@@ -916,7 +919,7 @@ test11 (GError **error)
 	value = gda_value_new_from_string ("my string", G_TYPE_STRING);
 	emitted_signals_reset ();
 	if (gda_holder_set_value (h, value, NULL)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's change should have failed");
 		return FALSE;
 	}
@@ -944,7 +947,7 @@ test11 (GError **error)
 	/***/
 	cvalue = gda_holder_get_value (h);
 	if (!cvalue || gda_value_differ (value, cvalue)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "GdaHolder's value is incorrect");
 		return FALSE;
 	}
@@ -967,7 +970,7 @@ test12 (GError **error)
 	/***/
 	value = gda_value_new_from_string ("my string", G_TYPE_STRING);
 	if (gda_holder_get_attribute (h, "attname1")) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "gda_holder_get_attribute() should have retunred NULL");
 		return FALSE;
 	}
@@ -975,13 +978,13 @@ test12 (GError **error)
 	gda_value_free (value);
 	cvalue = gda_holder_get_attribute (h, "attname1");
 	if (!cvalue) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "gda_holder_get_attribute() should have retunred a value");
 		return FALSE;
 	}
 	value = gda_value_new_from_string ("my string", G_TYPE_STRING);
 	if (gda_value_differ (cvalue, value)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "gda_holder_get_attribute() retunred a wrong value");
 		return FALSE;
 	}
@@ -994,12 +997,12 @@ test12 (GError **error)
 	copy = gda_holder_copy (h);
 	cvalue = gda_holder_get_attribute (copy, "attname1");
 	if (!cvalue) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "gda_holder_get_attribute() should have retunred a value");
 		return FALSE;
 	}
 	if (gda_value_differ (cvalue, value)) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "gda_holder_get_attribute() retunred a wrong value");
 		return FALSE;
 	}
@@ -1007,7 +1010,7 @@ test12 (GError **error)
 
 	g_object_get (G_OBJECT (copy), "name", &name, NULL);
 	if (strcmp (name, "thename")) {
-		g_set_error (error, 0, 0, "%s", 
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC, "%s", 
 			     "gda_holder_copy() did not copy the name");
 		return FALSE;
 	}
@@ -1033,7 +1036,7 @@ test13 (GError **error)
 	}
 	g_object_set (h2, "g-type", G_TYPE_STRING, NULL);
 	if (gda_holder_get_g_type (h1) != G_TYPE_STRING) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC,
 			     "%s", "Bind-to holder type set did not propagate to holder's type, case 1");
 		g_object_unref (h1);
 		g_object_unref (h2);
@@ -1051,7 +1054,7 @@ test13 (GError **error)
 		return FALSE;
 	}
 	if (gda_holder_get_g_type (h1) != G_TYPE_INT) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC,
 			     "%s", "Bind-to holder type set did not propagate to holder's type, case 2");
 		g_object_unref (h1);
 		g_object_unref (h2);
@@ -1070,14 +1073,14 @@ test13 (GError **error)
 	}
 	g_object_set (h2, "g-type", G_TYPE_STRING, NULL);
 	if (gda_holder_get_g_type (h1) != G_TYPE_STRING) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC,
 			     "%s", "Holder type changed when it should not have, case 1");
 		g_object_unref (h1);
 		g_object_unref (h2);
 		return FALSE;
 	}
 	if (gda_holder_get_bind (h1) != h2) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC,
 			     "%s", "Bind broken when it should not have been");
 		g_object_unref (h1);
 		g_object_unref (h2);
@@ -1096,14 +1099,14 @@ test13 (GError **error)
 	}
 	g_object_set (h2, "g-type", G_TYPE_INT, NULL);
 	if (gda_holder_get_g_type (h1) != G_TYPE_STRING) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC,
 			     "%s", "Holder type changed when it should not have, case 2");
 		g_object_unref (h1);
 		g_object_unref (h2);
 		return FALSE;
 	}
 	if (gda_holder_get_bind (h1) == h2) {
-		g_set_error (error, 0, 0,
+		g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC,
 			     "%s", "Bind not broken when it should have been");
 		g_object_unref (h1);
 		g_object_unref (h2);
@@ -1143,7 +1146,7 @@ emitted_signals_find (gpointer obj, const gchar *signal_name, GError **error)
 			return TRUE;
 		}
 	}
-	g_set_error (error, 0, 0,
+	g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC,
 		     "Signal \"%s\" has not been emitted", signal_name);
 	g_object_unref (obj);
 	return FALSE;
@@ -1157,7 +1160,7 @@ emitted_signals_notfind (gpointer obj, const gchar *signal_name, GError **error)
 		EmittedSignal *es = (EmittedSignal *) list->data;
 		if ((es->obj == obj) && (!strcmp (es->signal_name, signal_name))) {
 			signals_list = g_slist_delete_link (signals_list, list);
-			g_set_error (error, 0, 0,
+			g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC,
 				     "Signal \"%s\" has been emitted", signal_name);
 			g_object_unref (obj);
 
@@ -1175,7 +1178,7 @@ emitted_signals_check_empty (gpointer obj, const gchar *signal_name, GError **er
 		EmittedSignal *es = (EmittedSignal *) list->data;
 		if ((!obj || (es->obj == obj)) && 
 		    (!signal_name || (!strcmp (es->signal_name, signal_name)))) {
-			g_set_error (error, 0, 0,
+			g_set_error (error, TEST_ERROR, TEST_ERROR_GENERIC,
 				     "Signal \"%s\" has been emitted", es->signal_name);
 			emitted_signals_reset ();
 			return FALSE;
