@@ -27,7 +27,7 @@
 #include <sql-parser/gda-sql-parser.h>
 #include <libgda/gda-data-model-extra.h>
 #include <libgda/gda-sql-builder.h>
-
+#include <libgda/gda-debug-macros.h>
 #include "data-source-manager.h"
 
 /*#define DEBUG_SOURCES_SORT*/
@@ -66,7 +66,7 @@ data_source_manager_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		static const GTypeInfo info = {
 			sizeof (DataSourceManagerClass),
 			(GBaseInitFunc) NULL,
@@ -81,10 +81,10 @@ data_source_manager_get_type (void)
 		};
 
 		
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (G_TYPE_OBJECT, "DataSourceManager", &info, 0);
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 	}
 	return type;
 }
