@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2011 - 2012 Vivien Malerba <malerba@gnome-db.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,7 +24,7 @@
 #include "class-properties.h"
 #include "../dnd.h"
 #include "../support.h"
-#include "../cc-gray-bar.h"
+#include "../gdaui-bar.h"
 #include "../browser-page.h"
 #include "../browser-stock-icons.h"
 #include "../browser-window.h"
@@ -31,6 +32,7 @@
 #include <virtual/gda-ldap-connection.h>
 #include "mgr-ldap-classes.h"
 #include <libgda-ui/gdaui-tree-store.h>
+#include <libgda/gda-debug-macros.h>
 
 typedef struct {
 	gchar *classname;
@@ -61,26 +63,13 @@ struct _LdapClassesPagePrivate {
 static void ldap_classes_page_class_init (LdapClassesPageClass *klass);
 static void ldap_classes_page_init       (LdapClassesPage *ebrowser, LdapClassesPageClass *klass);
 static void ldap_classes_page_dispose   (GObject *object);
-static void ldap_classes_page_set_property (GObject *object,
-					  guint param_id,
-					  const GValue *value,
-					  GParamSpec *pspec);
-static void ldap_classes_page_get_property (GObject *object,
-					  guint param_id,
-					  GValue *value,
-					  GParamSpec *pspec);
+
 /* BrowserPage interface */
 static void                 ldap_classes_page_page_init (BrowserPageIface *iface);
 static GtkActionGroup      *ldap_classes_page_page_get_actions_group (BrowserPage *page);
 static const gchar         *ldap_classes_page_page_get_actions_ui (BrowserPage *page);
 static GtkWidget           *ldap_classes_page_page_get_tab_label (BrowserPage *page, GtkWidget **out_close_button);
 
-
-/* properties */
-enum {
-        PROP_0,
-};
-
 static GObjectClass *parent_class = NULL;
 
 
@@ -95,10 +84,6 @@ ldap_classes_page_class_init (LdapClassesPageClass *klass)
 
 	parent_class = g_type_class_peek_parent (klass);
 
-	/* Properties */
-        object_class->set_property = ldap_classes_page_set_property;
-        object_class->get_property = ldap_classes_page_get_property;
-
 	object_class->dispose = ldap_classes_page_dispose;
 }
 
@@ -179,36 +164,6 @@ ldap_classes_page_get_type (void)
 	return type;
 }
 
-static void
-ldap_classes_page_set_property (GObject *object,
-			      guint param_id,
-			      G_GNUC_UNUSED const GValue *value,
-			      GParamSpec *pspec)
-{
-	LdapClassesPage *ebrowser;
-	ebrowser = LDAP_CLASSES_PAGE (object);
-	switch (param_id) {
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
-		break;
-	}
-}
-
-static void
-ldap_classes_page_get_property (GObject *object,
-			      guint param_id,
-			      G_GNUC_UNUSED GValue *value,
-			      GParamSpec *pspec)
-{
-	LdapClassesPage *ebrowser;
-	ebrowser = LDAP_CLASSES_PAGE (object);
-	switch (param_id) {
-	default:
-		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
-		break;
-	}
-}
-
 static gchar *
 ldap_classes_page_to_selection (G_GNUC_UNUSED LdapClassesPage *ebrowser)
 {
@@ -360,7 +315,7 @@ ldap_classes_page_new (BrowserConnection *bcnc, const gchar *classname)
 	gchar *str;
 
 	str = g_strdup_printf ("<b>%s</b>", _("LDAP classes browser"));
-	label = cc_gray_bar_new (str);
+	label = gdaui_bar_new (str);
 	g_free (str);
         gtk_box_pack_start (GTK_BOX (ebrowser), label, FALSE, FALSE, 0);
         gtk_widget_show (label);
@@ -465,13 +420,13 @@ action_add_to_fav_cb (G_GNUC_UNUSED GtkAction *action, LdapClassesPage *ebrowser
 	classes_view_get_current_class (CLASSES_VIEW (ebrowser->priv->classes_view));
         memset (&fav, 0, sizeof (ToolsFavoritesAttributes));
         fav.id = -1;
-        fav.type = TOOLS_FAVORITES_LDAP_CLASS;
+        fav.type = GDA_TOOLS_FAVORITES_LDAP_CLASS;
         fav.name = ldap_classes_page_to_selection (ebrowser);
         fav.descr = NULL;
         fav.contents = ldap_classes_page_to_selection (ebrowser);
 
         bfav = browser_connection_get_favorites (ebrowser->priv->bcnc);
-        if (! tools_favorites_add (bfav, 0, &fav, ORDER_KEY_LDAP, G_MAXINT, &error)) {
+        if (! gda_tools_favorites_add (bfav, 0, &fav, ORDER_KEY_LDAP, G_MAXINT, &error)) {
                 browser_show_error ((GtkWindow*) gtk_widget_get_toplevel ((GtkWidget*) ebrowser),
                                     _("Could not add favorite: %s"),
                                     error && error->message ? error->message : _("No detail"));
@@ -552,9 +507,9 @@ static GtkActionEntry ui_actions[] = {
 	{ "LDAP", NULL, N_("_LDAP"), NULL, N_("LDAP"), NULL },
 	{ "AddToFav", STOCK_ADD_BOOKMARK, N_("Add to _Favorites"), NULL, N_("Add class to favorites"),
 	  G_CALLBACK (action_add_to_fav_cb)},
-	{ "DnBack", GTK_STOCK_GO_BACK, N_("Previous class"), NULL, N_("Move back to previous LDAP class"),
+	{ "DnBack", GTK_STOCK_GO_BACK, N_("Previous Class"), NULL, N_("Move back to previous LDAP class"),
 	  G_CALLBACK (action_class_back_cb)},
-	{ "DnForward", GTK_STOCK_GO_FORWARD, N_("Next class"), NULL, N_("Move to next LDAP class"),
+	{ "DnForward", GTK_STOCK_GO_FORWARD, N_("Next Class"), NULL, N_("Move to next LDAP class"),
 	  G_CALLBACK (action_class_forward_cb)},
 };
 static const gchar *ui_actions_browser =
