@@ -1,6 +1,7 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,7 +26,7 @@
 #include <libgda-ui/gdaui-tree-store.h>
 #include "../dnd.h"
 #include "../support.h"
-#include "../cc-gray-bar.h"
+#include "../gdaui-bar.h"
 #include "marshal.h"
 #include <gdk/gdkkeysyms.h>
 #include <libgda-ui/internal/popup-container.h>
@@ -34,7 +35,6 @@
 struct _ObjectsIndexPrivate {
 	BrowserConnection *bcnc;
 	ObjectsCloud      *cloud;
-	GtkWidget         *popup_container;
 };
 
 static void objects_index_class_init (ObjectsIndexClass *klass);
@@ -94,7 +94,6 @@ objects_index_dispose (GObject *object)
 
 	/* free memory */
 	if (index->priv) {
-		gtk_widget_destroy (index->priv->popup_container);
 		if (index->priv->bcnc) {
 			g_signal_handlers_disconnect_by_func (index->priv->bcnc,
 							      G_CALLBACK (meta_changed_cb), index);
@@ -137,11 +136,17 @@ cloud_object_selected_cb (G_GNUC_UNUSED ObjectsCloud *sel, G_GNUC_UNUSED Objects
 {
 	/* FIXME: adjust with sel->priv->type */
 	g_signal_emit (index, objects_index_signals [SELECTION_CHANGED], 0,
-		       TOOLS_FAVORITES_TABLES, sel_contents);
+		       GDA_TOOLS_FAVORITES_TABLES, sel_contents);
+}
+
+static void
+find_changed_cb (GtkEntry *entry, ObjectsIndex *index)
+{
+	objects_cloud_filter (index->priv->cloud, gtk_entry_get_text (entry));
 }
 
 /**
- * objects_index_new
+ * objects_index_new:
  *
  *
  *
@@ -168,7 +173,7 @@ objects_index_new (BrowserConnection *bcnc)
 	gchar *str;
 
 	str = g_strdup_printf ("<b>%s</b>", _("Tables' index"));
-	label = cc_gray_bar_new (str);
+	label = gdaui_bar_new (str);
 	g_free (str);
         gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
         gtk_widget_show (label);
@@ -184,23 +189,11 @@ objects_index_new (BrowserConnection *bcnc)
 	g_signal_connect (cloud, "selected",
 			  G_CALLBACK (cloud_object_selected_cb), index);
 
-	/* find button */
-	wid = gtk_button_new ();
-	label = gtk_image_new_from_stock (GTK_STOCK_FIND, GTK_ICON_SIZE_BUTTON);
-	gtk_container_add (GTK_CONTAINER (wid), label);
-	gtk_box_pack_start (GTK_BOX (hbox), wid, FALSE, FALSE, 0);
-	g_object_set (G_OBJECT (wid), "label", NULL, NULL);
+	/* search entry */
+	wid = gdaui_bar_add_search_entry (GDAUI_BAR (label));
 	
-	GtkWidget *popup;
-	popup = popup_container_new (wid);
-	index->priv->popup_container = popup;
-	g_signal_connect_swapped (wid, "clicked",
-				  G_CALLBACK (gtk_widget_show), popup);
-	g_object_set_data (G_OBJECT (popup), "button", wid);
-
-	wid = objects_cloud_create_filter (OBJECTS_CLOUD (cloud));
-	gtk_container_add (GTK_CONTAINER (popup), wid);
-	gtk_widget_show (wid);
+	g_signal_connect (wid, "changed",
+			  G_CALLBACK (find_changed_cb), index);
 
 	return (GtkWidget*) index;
 }
