@@ -1,6 +1,7 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2009 - 2012 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,7 +23,7 @@
 #include "table-info.h"
 #include "../dnd.h"
 #include "../support.h"
-#include "../cc-gray-bar.h"
+#include "../gdaui-bar.h"
 #include "table-columns.h"
 #include "table-preferences.h"
 #ifdef HAVE_GOOCANVAS
@@ -38,6 +39,7 @@
 #include <libgda-ui/internal/popup-container.h>
 #include <libgda/gda-data-model-extra.h>
 #include "../common/fk-declare.h"
+#include <libgda/gda-debug-macros.h>
 
 struct _TableInfoPrivate {
 	BrowserConnection *bcnc;
@@ -46,7 +48,7 @@ struct _TableInfoPrivate {
 	gchar *table_name;
 	gchar *table_short_name;
 
-	CcGrayBar *header;
+	GdauiBar *header;
 	GtkWidget *contents; /* notebook with pageO <=> @unknown_table_notice, page1 <=> @pages */
 	GtkWidget *unknown_table_notice;
 	GtkWidget *pages; /* notebook to store individual pages */
@@ -331,11 +333,11 @@ table_info_new (BrowserConnection *bcnc,
 	tmp = g_strdup_printf (_("In schema '%s'"), schema);
 	str = g_strdup_printf ("<b>%s</b>\n%s", table, tmp);
 	g_free (tmp);
-	label = cc_gray_bar_new (str);
+	label = gdaui_bar_new (str);
 	g_free (str);
         gtk_box_pack_start (GTK_BOX (tinfo), label, FALSE, FALSE, 0);
         gtk_widget_show (label);
-	tinfo->priv->header = CC_GRAY_BAR (label);
+	tinfo->priv->header = GDAUI_BAR (label);
 
 	/* main contents */
 	GtkWidget *top_nb;
@@ -456,13 +458,13 @@ action_add_to_fav_cb (G_GNUC_UNUSED GtkAction *action, TableInfo *tinfo)
 
         memset (&fav, 0, sizeof (ToolsFavoritesAttributes));
         fav.id = -1;
-        fav.type = TOOLS_FAVORITES_TABLES;
+        fav.type = GDA_TOOLS_FAVORITES_TABLES;
         fav.name = NULL;
         fav.descr = NULL;
         fav.contents = table_info_to_selection (tinfo);
 
         bfav = browser_connection_get_favorites (tinfo->priv->bcnc);
-        if (! tools_favorites_add (bfav, 0, &fav, ORDER_KEY_SCHEMA, G_MAXINT, &error)) {
+        if (! gda_tools_favorites_add (bfav, 0, &fav, ORDER_KEY_SCHEMA, G_MAXINT, &error)) {
                 browser_show_error ((GtkWindow*) gtk_widget_get_toplevel ((GtkWidget*) tinfo),
                                     _("Could not add favorite: %s"),
                                     error && error->message ? error->message : _("No detail"));
@@ -989,9 +991,9 @@ static GtkActionEntry ui_actions[] = {
 	  G_CALLBACK (action_add_to_fav_cb)},
 	{ "ViewContents", GTK_STOCK_EDIT, N_("_Contents"), NULL, N_("View table's contents"),
 	  G_CALLBACK (action_view_contents_cb)},
-	{ "InsertData", GTK_STOCK_ADD, N_("_Insert data"), NULL, N_("Insert data into table"),
+	{ "InsertData", GTK_STOCK_ADD, N_("_Insert Data"), NULL, N_("Insert data into table"),
 	  G_CALLBACK (action_insert_cb)},
-	{ "KfDeclare", NULL, N_("_Declare foreign key"), NULL, N_("Declare a foreign key for table"),
+	{ "KfDeclare", NULL, N_("_Declare Foreign Key"), NULL, N_("Declare a foreign key for table"),
 	  G_CALLBACK (action_declarefk_cb)},
 };
 static const gchar *ui_actions_info =
